#
# spec file for package python-pivy
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define skip_python2 1
#%%define skip_python39 1
#%%define skip_python310 1

Name:           python-pivy
Version:        0.6.9
Release:        1.2
Summary:        Coin Binding for Python
# GPL only applies to some examples
License:        GPL-2.0-only AND ISC
Group:          Development/Libraries/Python
URL:            https://github.com/coin3d/pivy
Source0:        https://github.com/coin3d/pivy/archive/%{version}.tar.gz#/pivy-%{version}.tar.gz
BuildRequires:  %{python_module devel}
BuildRequires:  %{python_module setuptools}
BuildRequires:  cmake
BuildRequires:  fdupes
BuildRequires:  gcc
BuildRequires:  python-rpm-macros
BuildRequires:  swig
BuildRequires:  cmake(soqt)
%python_subpackages

%description
Pivy is a Coin binding for Python. Coin is a high-level 3D graphics library
with a C++ Application Programming Interface. Coin uses scene-graph data
structures to render real-time graphics suitable for mostly all kinds of
scientific and engineering visualization applications.

Pivy allows:

- Development of Coin applications and extensions in Python
- Interactive modification of Coin programs from within the Python interpreter
  at runtime
- Incorporation of Scripting Nodes into the scene graph which are capable of
  executing Python code and callbacks

%prep
%autosetup -p1 -n pivy-%{version}
%if 0%{suse_version} < 1550
sed -i -e '/find_package/ s/SWIG 4.0.0/SWIG/' CMakeLists.txt
%endif
# Coin 4.0.2 compat - see https://github.com/coin3d/pivy/pull/111
touch fake_headers/cmath

%build
%{python_expand #
%define __builddir build_%{$python_bin_suffix}
pushd .
%cmake \
  -DPython_EXECUTABLE:FILEPATH=%{_bindir}/python%{$python_bin_suffix}
  %{nil}
popd
}

%{python_expand #
%define __builddir build_%{$python_bin_suffix}
pushd %{__builddir}
%cmake_build
popd
}

%install
%{python_expand #
%define __builddir build_%{$python_bin_suffix}
%cmake_install
$python ./setup.py install_egg_info --install-dir %{buildroot}%{$python_sitearch}
find %{buildroot}%{$python_sitearch} -iname \*sogui.py -exec sed -i -e '1 s@env python@python%{$python_bin_suffix}@' '{}' \; -exec chmod +x '{}' \;
%fdupes %{buildroot}%{$python_sitearch}/pivy/
}

%files %{python_files}
%license LICENSE
%doc AUTHORS HACKING NEWS README.md THANKS
%{python_sitearch}/pivy/
%{python_sitearch}/Pivy-%{version}-py%{python_version}.egg-info

%changelog
* Sat Jan 18 2025 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- update to 0.6.9:
  * Python 3.12/Qt6 support
- Drop upstream patches:
  * fix_python_312_replace_PyEval_CallObject.patch
  * fix_python_312_PyUnicode_usage.patch
* Thu Apr 11 2024 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Fix build with Python 3.12, BuildRequire python-setuptools, add
  * fix_python_312_replace_PyEval_CallObject.patch
  * fix_python_312_PyUnicode_usage.patch
* Sat Jan  6 2024 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Fix compatibility with SoQt 1.6.2/Coin3D 4.0.2
* Wed Jan  4 2023 Dirk Müller <dmueller@suse.com>
- update to 0.6.8:
  * fix cast issue
* Mon May  2 2022 Hans-Peter Jansen <hpj@urpla.net>
- Update to 0.6.7:
  * aiming at python3.10 support
- Remove upstreamed fix_python_installdir.patch
* Mon Mar 14 2022 Dominique Leuenberger <dimstar@opensuse.org>
- Fix one more case where sed env python was replaced with
  python38 instead of python3.8.
* Fri Mar 11 2022 Dominique Leuenberger <dimstar@opensuse.org>
- Fix name of python interpreter executables (python3.8 instead of
  python38).
* Wed Feb 23 2022 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Update to 0.6.6:
  * finalizing cmake support
  * adding bindings to SoGeo*
- Drop 0001-Allow-using-SoQt-snapshots-with-stable-Coin-version.patch
- Use arch specific directory, add fix_python_installdir.patch
- Use cmake for building, drop
  0002-Fix-the-qmake-executable-name.patch.
* Thu May  7 2020 Atri Bhattacharya <badshah400@gmail.com>
- Use correct macro %%{python_version} instead of %%{py_ver} to
  pack egg-info file.
- Drop macro definitions needed for obsolete openSUSE versions.
* Sat Mar 14 2020 Hans-Peter Jansen <hpj@urpla.net>
- Update to 0.6.5
  - Unifying release for merge of FreeCAD/pivy and
    bitbucket.org/coin3d/pivy repos
  - change pivy.graphics API to follow pep8 naming scheme
    suggestion.
  - workaround for beveled text
  - swig4.0 fix
  - update to latest coin (additional fakeheaders)
  - example Complex3dText: add license and shebang
    this was unintentional removed at some point
- Remove Fix-issue-39-PyUnicode_AsUTF8-returns-const-char.patch
  applied upstream
- 0001-Allow-using-SoQt-snapshots-with-stable-Coin-version.patch
  adjusted
* Mon May 13 2019 Christophe Giboudeaux <christophe@krop.fr>
- Add 0001-Allow-using-SoQt-snapshots-with-stable-Coin-version.patch
  This will allow using SoQt snapshots with stable Coin releases.
- Add 0002-Fix-the-qmake-executable-name.patch. The qmake executable
  is called qmake-qt5 for openSUSE.
- Run spec-cleaner
* Mon Feb  4 2019 Wolfgang Bauer <wbauer@tmo.at>
- Add Fix-issue-39-PyUnicode_AsUTF8-returns-const-char.patch to fix
  build in Factory
* Tue Oct  9 2018 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Update to 0.6.3
  * qt5-support (qt4 not supported anymore)
- Update to 0.6.4
  * bool(coin.SoGroup) -> True (also if group is empty) [same behaviour as py2]
  * add graphics arrow object
  * making it possible to compile with older coin version (without cmake) -> setup_old.py
  * adding back qt4 compatibility (but tests are still qt5 depenent)
  * added pivy.version
  * some fixes
- %%python_expand call to fdupes
* Wed Jan  3 2018 dev@stellardeath.org
- Fix build failure when using more than one python version:
  swig wrapper files were only generated the first time and
  and then kept for subsequent builds.
* Sat Dec 16 2017 badshah400@gmail.com
- Convert specfile to python-singlespec: fixes build failures in
  Factory. Doesn't build against python2 for unknown reasons, so
  turn off python2 modules until this is fixed.
- Use fdupes (added to BuildRequires) to link duplicate files.
* Thu Sep 14 2017 kkaempf@suse.com
- update to 0.6.2
  * builds for python3 (linux: 3.4, 3.5, 3.6; win: 3.5, 3.6)
    or python2 (2.7)
  * uses pyside instead of pyqt for soqt4 bindings
  * has many fixes (especially for FreeCAD)
- switch to github.com/FreeCAD/pivy, coin3d.org is dead
* Sat May  5 2012 asterios.dramis@gmail.com
- Initial release (version 0.5.0hg.609).
